--------------------------------------------------------------------------------
-- Copyright  2021								|
-- All Rights Reserved.								|
-- 										|
-- Permission to use, copy, modify, and distribute this software in any way	|
-- is not granted without expressed written agreement. This copyright applies	|
-- to the all code, data and artwork related to this project and all associated	|
-- projects published by the author.						|
--										|
-- More information on copyright is available from sources on-line.		|
-- Use an actual factual one!							|
--------------------------------------------------------------------------------

local _, NS = ...

local ABDB

local upper, gsub = string.upper, string.gsub

local AddonName = "AutoBar"
local Scale = 1
local MainScale = 1
local Padding = 0
local ClassList, ClassLookup, Hooked, IsInit, Timer

function NS.SetAutoBarScales()
	if NS.Versions[AddonName][WOW_PROJECT_ID] and NS.Versions[AddonName][WOW_PROJECT_ID].scale then
		local Settings = NS.Versions[AddonName][WOW_PROJECT_ID]
		Scale = Settings.scale
		MainScale = Settings.mainscale
		Padding = Settings.padding
	end
	return Scale, MainScale, Padding
end

local Extensions = {
	"",
	"Classic",
	"BCC",
	"Wrath",
}
local function IsLoaded(deactivate)
	local LoadCheck = AddonName
	for k, v in  pairs(Extensions) do
		if IsAddOnLoaded(LoadCheck..v) then 
			ABDB = AutoBarDB or AutoBarDB2
			return true
		end
	end
	if deactivate then
		NS:GetSettings("Addons")[AddonName].inactive = true
	else
		NS.DebugPrint("Not Found:", AddonName)
	end
end

local function AssignAutoBar(reset)
	if not IsLoaded(true) then
		return
	end
	local yos = NS.Versions[AddonName][WOW_PROJECT_ID].mainyos
--[[
	local LoadCheck = AddonName.."Classic"
	if not IsAddOnLoaded(LoadCheck) then 
		LoadCheck = AddonName
		if not IsAddOnLoaded(LoadCheck) then 
			NS:GetSettings("Addons")[AddonName].inactive = true
			return 
		end
	end
]]--
	if not ClassList then
		ClassList = {}
		ClassLookup = {}
		for k, v in pairs(ABDB.classes) do 
			ClassList[upper(gsub(k, " ", ""))] = v
			ClassLookup[upper(gsub(k, " ", ""))] = gsub(k, " ", "")
		end
	end
	local Class = UnitClass("player")
	local BarClass = string.gsub(Class, " ", "")
	local ClassBar = _G["AutoBarClassBar"..BarClass.."Driver"]
	if ClassBar then
		NS.SetAutoBarScales()
		ClassBar:SetScale(Scale)
		ClassBar:ClearAllPoints()
		ClassBar:SetPoint("BOTTOMLEFT", DominosFrame1, "TOPLEFT", 0, -2)
		ClassBar.class:PositionSave()
		local es = ClassBar:GetEffectiveScale()
		local posX = ClassBar:GetLeft() * es
		local posY = ClassBar:GetBottom() * es
--		local Settings = ABDB.classes[Class].barList["AutoBarClassBar"..BarClass]
		for i=1, #CLASS_SORT_ORDER do 
			local Settings = ClassList[CLASS_SORT_ORDER[i]]
			if Settings then 
				Settings = Settings.barList["AutoBarClassBar"..ClassLookup[CLASS_SORT_ORDER[i]]]
				if Settings then
					Settings.posX = posX
					Settings.posY = posY
					Settings.scale = Scale
					Settings.padding = Padding
				end
			end
		end
	end
	if IsInit or reset then
		IsInit = false
		local StartTime = reset and 0.2 or 2
		C_Timer.After(StartTime, function()
			print(" ")
			local ABasic = _G["AutoBarClassBarBasicDriver"]
			local Trink = NS:GetFrame("Utility", "Trinket2")
			ABasic:SetScale(MainScale)
			ABasic:ClearAllPoints()
			ABasic:SetPoint("BOTTOMLEFT", Trink, "BOTTOMRIGHT", 0, yos)-- -4)
			ABasic.FMSetPoint = ABasic.SetPoint
			ABasic.SetPoint = function() end
			ABasic:Show()
			local left = ABasic:GetLeft()
			local bottom = ABasic:GetBottom()
			local scale = ABasic:GetEffectiveScale()
			if left and bottom then
				ABDB.account.barList.AutoBarClassBarBasic.posX = left * scale
				ABDB.account.barList.AutoBarClassBarBasic.posY = bottom * scale
				ABDB.account.barList.AutoBarClassBarBasic.scale = MainScale
			end
		end)
		if IsInit and MuffinWhatsNewFrame then
			MuffinWhatsNewFrame:HookScript("OnShow", function(self) 
				self:Hide()
			end)
		end
	end
	LibStub("AceConfigRegistry-3.0"):NotifyChange(AddonName) ----------- Need to see if this does anything positive
end

local function KillKey(table, value, iskey)
	for k, v in pairs(table) do
		if (iskey and k == value) or (not iskey and v == value) then
			table[k] = nil
		end
	end
end
local function ConfigureAutoBar(reset)
	if not IsLoaded() then
		return
	end
--[[
	local LoadCheck = AddonName.."Classic"
	if not IsAddOnLoaded(LoadCheck) then 
		LoadCheck = AddonName
		if not IsAddOnLoaded(LoadCheck) then 
			NS.DebugPrint("Not Found:", AddonName)
			return
		end
	end
]]--
	local GetFrame = NS:GetOption("GetFrame")
	local FauxMazzle
	FauxMazzle = NS:LoadSettingsAutoBar()
	if NS:IsValidVersion(NS.WOW_Project.Burning_Crusade_Classic) or NS:IsValidVersion(NS.WOW_Project.WrathClassic) then
		KillKey(FauxMazzle.account.barList.AutoBarClassBarBasic.buttonKeys, "AutoBarButtonCooldownPotionHealth")
		KillKey(FauxMazzle.account.barList.AutoBarClassBarBasic.buttonKeys, "AutoBarButtonCooldownPotionMana")
		KillKey(FauxMazzle.account.buttonList, "AutoBarButtonCooldownPotionHealth", true)
		KillKey(FauxMazzle.account.buttonList, "AutoBarButtonCooldownPotionMana", true)
	end
	NS.SetAutoBarScales()
	if AutoBarClassBarExtrasDriver then
		AutoBarClassBarExtrasDriver:ClearAllPoints()
		AutoBarClassBarExtrasDriver:SetPoint("LEFT", UIParent, "RIGHT", 20, 0)
	end
	for k,v in pairs(FauxMazzle.classes) do
		if v.barList then
			for _, bar in pairs(v.barList) do
				bar.scale = Scale
			end
		end
	end
	IsInit = true
	ABDB.account.barList = {}
	ABDB.classes = {}
	NS.Lib:CopyTable(FauxMazzle.classes, ABDB.classes, NS.Lib.SaveTables)
	NS.Lib:CopyTable(FauxMazzle.account, ABDB.account, NS.Lib.SaveTables)
end

NS:AddConfig(2, AddonName, AddonName, ConfigureAutoBar, AssignAutoBar)
